"""Console script for pystv."""
import click

import pystv


@click.command()
@click.option(
    "--csvfile",
    help="CSV output of a Google Form with one or more ranked-choice voting questions.",
)
@click.option("--details", is_flag=True, help="Include round-by-round results.")
def main(csvfile, details):
    with open(csvfile) as buffer:
        races = pystv.parse_google_form_csv(buffer)

    for race in races:
        result = pystv.run_stv(race)

        if details:
            print(result)
        else:
            print(f"race: {race.metadata.race_name}")
            names = result.metadata.names
            # -1 because the elected indexing starts from 1.
            winners = ", ".join(
                [names[e - 1] for r in result.rounds for e in r.elected]
            )
            print(f"winner(s): {winners}")

    return 0


if __name__ == "__main__":
    main()
